package com.mints.goodmoney.ui.fragment

import android.annotation.SuppressLint
import android.text.TextUtils
import android.view.View
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.DividerItemDecoration
import androidx.recyclerview.widget.RecyclerView
import androidx.viewpager.widget.ViewPager
import cn.sharesdk.framework.Platform
import cn.sharesdk.framework.ShareSDK
import cn.sharesdk.wechat.friends.Wechat
import com.mints.goodmoney.R
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.model.FriendHallMsgBean
import com.mints.goodmoney.mvp.presenters.FriendsPresenter
import com.mints.goodmoney.mvp.views.FriendsView
import com.mints.goodmoney.ui.activitys.FriendsActivity
import com.mints.goodmoney.ui.adapter.FriendsPagerAdapter
import com.mints.goodmoney.ui.adapter.InvitedAdapter
import com.mints.goodmoney.ui.fragment.base.BaseFragment
import com.mints.goodmoney.ui.widgets.BonusDialog
import com.mints.goodmoney.ui.widgets.DialogListener
import com.mints.goodmoney.utils.ImageUtil
import com.mints.goodmoney.utils.SpanUtils
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import kotlinx.android.synthetic.main.fragment_main_friends.*
import kotlinx.android.synthetic.main.header_layout.*

/**
 * 描述：邀请好友
 * 作者：孟崔广
 * 时间：2020/9/20 17:30
 */
class FriendsFragment : BaseFragment(), FriendsView, OnRefreshListener, View.OnClickListener {

    private val friendsPresenter by lazy { FriendsPresenter() }

    private var viewPagerAdapter: FriendsPagerAdapter? = null

    // 收益总榜数据
    private var allData: MutableList<FriendHallMsgBean.ListBean> = mutableListOf()
    private var allAdapter: InvitedAdapter? = null

    // 今日贡献榜数据
    private var todayData: MutableList<FriendHallMsgBean.ListBean> = mutableListOf()
    private var todayAdapter: InvitedAdapter? = null

    // 昨日收益榜数据
    private var yesterdayData: MutableList<FriendHallMsgBean.ListBean> = mutableListOf()
    private var yesterdayAdapter: InvitedAdapter? = null

    private val recyList: MutableList<RecyclerView> = mutableListOf()

    private var mFriendsHallMsgBean: FriendHallMsgBean? = null

    private var bonusDialog: BonusDialog? = null

    override fun getContentViewLayoutID() = R.layout.fragment_main_friends

    override fun initViewsAndEvents() {
        friendsPresenter.attachView(this)
        srl_my.setOnRefreshListener(this)

        initView()
        initRecy()
    }

    @SuppressLint("ClickableViewAccessibility")
    private fun initView() {
        tv_right_subtitle.visibility = View.VISIBLE
        tv_right_subtitle.text = "玩法规则"
        tv_right_subtitle.setTextColor(resources.getColor(R.color.main_bg_text))
        tv_right_subtitle.setOnClickListener { }
        tv_title.text = "瓜分百万现金福利"

        btn_get_bonus.setOnClickListener(this)
        tv_right_subtitle.setOnClickListener(this)
        btn_invite.setOnClickListener(this)
        tv_detail.setOnClickListener(this)
        tv_friends_directly.setOnClickListener(this)
        tv_friends_indirect.setOnClickListener(this)
    }

    private fun initRecy() {
        val recyAll = View.inflate(mContext, R.layout.item_friends_recy, null) as RecyclerView
        val recyToday = View.inflate(mContext, R.layout.item_friends_recy, null) as RecyclerView
        val recyYesterday = View.inflate(mContext, R.layout.item_friends_recy, null) as RecyclerView

        recyAll.addItemDecoration(DividerItemDecoration(mContext, DividerItemDecoration.VERTICAL))
        recyToday.addItemDecoration(DividerItemDecoration(mContext, DividerItemDecoration.VERTICAL))
        recyYesterday.addItemDecoration(DividerItemDecoration(mContext, DividerItemDecoration.VERTICAL))

        allAdapter = InvitedAdapter(mContext, allData)
        yesterdayAdapter = InvitedAdapter(mContext, yesterdayData)
        todayAdapter = InvitedAdapter(mContext, todayData)

        recyAll.adapter = allAdapter
        recyToday.adapter = todayAdapter
        recyYesterday.adapter = yesterdayAdapter

        recyList.add(recyAll)
        recyList.add(recyToday)
        recyList.add(recyYesterday)

        val titleList = arrayListOf("总收益榜", "今日贡献榜", "昨日收益榜")
        viewPagerAdapter = FriendsPagerAdapter(titleList, recyList)
        view_pager_friends.adapter = viewPagerAdapter
        view_pager_friends.addOnPageChangeListener(object : ViewPager.OnPageChangeListener {
            override fun onPageScrolled(position: Int, positionOffset: Float, positionOffsetPixels: Int) {
            }

            override fun onPageSelected(position: Int) {
                when (position) {
                    0 -> {
                        if (allData.size <= 0) {
                            friendsPresenter.getContributionBigLeaders()
                        }
                    }
                    1 -> {
                        if (todayData.size <= 0) {
                            friendsPresenter.getFriendsGiveTodayList()
                        }
                    }
                    2 -> {
                        if (yesterdayData.size <= 0) {
                            friendsPresenter.getContributionLeaders()
                        }
                    }
                }
            }

            override fun onPageScrollStateChanged(state: Int) {
            }

        })

        tab_friends.setupWithViewPager(view_pager_friends)

    }

    override fun onHiddenChanged(hidden: Boolean) {
        if (hidden) { // 不在最前端界面显示
            onPause()
        } else { // 重新显示到最前端中
            onResume()
        }
        super.onHiddenChanged(hidden)
    }

    override fun onResume() {
        super.onResume()
        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_FRIENDS) {
            if (!TextUtils.isEmpty(UserManager.getInstance().userID)) {
                // 刷新分红数据
                friendsPresenter.getFriendHallMsg()

                when (view_pager_friends.currentItem) {
                    0 -> {
                        friendsPresenter.getContributionBigLeaders()
                    }
                    1 -> {
                        friendsPresenter.getFriendsGiveTodayList()
                    }
                    2 -> {
                        friendsPresenter.getContributionLeaders()

                    }
                    else -> {
                    }
                }
            }
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        friendsPresenter.detachView()
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        if (UserManager.getInstance().userID.isNotEmpty()) {
            // 刷新分红数据
            friendsPresenter.getFriendHallMsg()

            when (view_pager_friends.currentItem) {
                0 -> {
                    friendsPresenter.getContributionBigLeaders()
                }
                1 -> {
                    friendsPresenter.getFriendsGiveTodayList()
                }
                2 -> {
                    friendsPresenter.getContributionLeaders()
                }
                else -> {
                }
            }
        }
    }

    private fun generateData(data: FriendHallMsgBean) {
        if (TextUtils.isEmpty(data.button)) {
            btn_get_bonus.text = "结算中"
        }

        friends_sum.text = "" + data.friendCount
        friends_directly_sum.text = "" + data.directFriendsCount
        friends_indirect_sum.text = "" + data.indirectFriendsCount

        btn_get_bonus.isEnabled = data.status == 0 && data.cash.toInt() > 0

        tv_bonus_date.text = data.periods

        tv_bonus_sum.text = SpanUtils()
                .append("预计总分红 ").setForegroundColor(resources.getColor(R.color.black))
                .append(data.titleMsg).setFontSize(52).setForegroundColor(resources.getColor(R.color.color_E72C2B))
                .append(" 元").setForegroundColor(resources.getColor(R.color.black))
                .create()

        tv_yesterday_bonus.text = SpanUtils()
                .append(data.contribution_yesterday.toString()).setForegroundColor(resources.getColor(R.color.color_FF7C00))
                .create()

        tv_today_bonus.text = SpanUtils()
                .append(data.contribution_today.toString()).setForegroundColor(resources.getColor(R.color.color_E72C2B))
                .create()

        tv_bonus_money.text = SpanUtils()
                .append(data.cash.toString()).setFontSize(50).setForegroundColor(resources.getColor(R.color.color_E72C2B))
                .append("元").setFontSize(30).setForegroundColor(resources.getColor(R.color.color_E72C2B))
                .create()

        tv_bonus_rate.text = SpanUtils()
                .append("昨日汇率：").setForegroundColor(resources.getColor(R.color.black))
                .append(data.rate).setForegroundColor(resources.getColor(R.color.color_E72C2B))
                .create()
    }

    private fun hintDialog(flag: Boolean) {
        bonusDialog = BonusDialog(requireActivity(), object : DialogListener() {
            override fun onClick(v: View) {
                when (v.id) {
                    R.id.btn_submit -> {
                        if (activity != null && !activity!!.isFinishing &&
                                bonusDialog != null && bonusDialog!!.isShowing
                        ) {
                            bonusDialog!!.dismiss()
                        }
                    }
                }
            }
        })
        bonusDialog?.let {
            if (flag) {
                it.setTitle("什么是直接亲友？")
                it.setContent("经你本人直接邀请的亲友，就是你的直接亲友。")
                it.setBtnStr("知道了")
            } else {
                it.setTitle("什么是间接亲友？")
                it.setContent("经你直接亲友邀请的亲友，就是你的间接亲友。")
                it.setBtnStr("知道了")
            }
            it.show()
        }
    }

    private fun ruleDialog() {
        if (mFriendsHallMsgBean?.rules != null) {
            bonusDialog = BonusDialog(requireActivity(), object : DialogListener() {
                override fun onClick(v: View) {
                    when (v.id) {
                        R.id.btn_submit -> {
                            if (activity != null && !activity!!.isFinishing &&
                                    bonusDialog != null && bonusDialog!!.isShowing
                            ) {
                                bonusDialog!!.dismiss()
                            }
                        }
                    }
                }
            })
            bonusDialog?.let {
                it.setTitle("玩法规则")
                it.setContent(mFriendsHallMsgBean?.rules!!)
                it.setBtnStr("知道了")
                it.show()
            }
        }
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.tv_detail -> {
                // 亲友团详情
                readyGo(FriendsActivity::class.java)
            }
            R.id.tv_friends_directly -> {
                // 直接亲友弹框
                hintDialog(true)
            }
            R.id.tv_friends_indirect -> {
                // 间接亲友弹框
                hintDialog(false)
            }
            R.id.btn_invite -> {
                // 邀请好友
                val wechatSp = Platform.ShareParams()
                wechatSp.shareType = Platform.SHARE_WEBPAGE
                wechatSp.title = Constant.SHARE_TITLE
                wechatSp.text = Constant.SHARE_CONTENT
                wechatSp.imageData = ImageUtil.drawableToBitmap(ContextCompat.getDrawable(requireContext(), R.mipmap.ic_launcher))
                wechatSp.url = Constant.SHARE_URL
                val wechat = ShareSDK.getPlatform(Wechat.NAME)
                if (wechat.isClientValid) {
                    // 执行图文分享
                    wechat.share(wechatSp)
                } else {
                    showToast("请先安装微信")
                }

            }
            R.id.tv_right_subtitle -> {
                // 玩法规则
                ruleDialog()
            }
            R.id.btn_get_bonus -> {
                // 领取收益
                mFriendsHallMsgBean?.let {
                    if (it.cash.toInt() > 0 && it.status == 0) {
                        // 去提现
                        friendsPresenter.getContributionOutToCash()
                    } else {
                        showToast("您的贡献值未达到提现要求")
                    }
                }

            }
        }
    }

    // 总收益榜
    override fun getContributionBigLeadersSuc(data: FriendHallMsgBean) {
        srl_my.finishRefresh(true)

        allData.clear()
        allData.addAll(data.list)
        allAdapter?.notifyDataSetChanged()
    }

    override fun getFriendsHallMsgSuc(data: FriendHallMsgBean) {
        srl_my.finishRefresh(true)
        mFriendsHallMsgBean = data
        generateData(data)
    }

    // 昨日收益榜
    override fun getContributionLeadersSuc(data: FriendHallMsgBean) {
        srl_my.finishRefresh(true)

        yesterdayData.clear()
        yesterdayData.addAll(data.list)
        yesterdayAdapter?.notifyDataSetChanged()
    }

    // 今日贡献榜
    override fun getFriendsGiveTodayListSuc(data: FriendHallMsgBean) {
        srl_my.finishRefresh(true)

        todayData.clear()
        todayData.addAll(data.list)
        todayAdapter?.notifyDataSetChanged()
    }

    // 提现成功
    override fun getContributionOutToCashSuc() {
        showToast("提现成功")
    }

}